"""Configuration module for RCLCO library."""

from rclco.config.settings import (
    AZURE_KEYVAULT_URL,
    DATABASE_REGISTRY,
    API_REGISTRY,
    BLOB_REGISTRY,
    SHAREPOINT_CONFIG,
)

__all__ = [
    "AZURE_KEYVAULT_URL",
    "DATABASE_REGISTRY",
    "API_REGISTRY",
    "BLOB_REGISTRY",
    "SHAREPOINT_CONFIG",
]
